@@ -1,3 +1,5 @@
+import pickle
+
 import requests
 from bs4 import BeautifulSoup
 from selenium import webdriver
@@ -122,6 +124,15 @@ class Web:
         :param url: The url of the page to open
         """
         self.downloaddir = r"\temp"
+        self.url = url
+        self.soup = None
+        self.__connect__()
+
+    def __connect__(self):
+        """
+        Internal function to connect to the web page
+        :return: None
+        """
         options = webdriver.ChromeOptions()
         options.add_experimental_option("prefs", {
             "download.default_directory": self.downloaddir,
@@ -131,12 +142,40 @@ class Web:
         })
         self.driver = webdriver.Chrome(service=Service(ChromeDriverManager().install()), options=options)
         self.wait = WebDriverWait(self.driver, 20)
-        self.url = url
-        self.soup = None
         if self.url != "":
             self.driver.get(self.url)
             self.soup = BeautifulSoup(self.driver.page_source, 'html.parser')
 
+    def __is_picklable__(self, obj: any) -> bool:
+        """
+        Internal function to determine if the object is pickable.
+        :param obj: The object to check.
+        :return: True or False
+        """
+        try:
+            pickle.dumps(obj)
+            return True
+        except Exception as e:
+            return False
+
+    def __getstate__(self):
+        """
+        Internal function for serialization
+        """
+        state = self.__dict__.copy()
+        for key, val in state.items():
+            if not self.__is_picklable__(val):
+                state[key] = str(val)
+        return state
+
+    def __setstate__(self, state):
+        """
+        Internal function for deserialization
+        :param state: The state to set to the 'self' object of the class
+        """
+        self.__dict__.update(state)
+        self.__connect__()
+
     def get_text_by_id(self, id):
         """
         Get the text of a html element of the page by its ID.
